from lxml import etree
from classytags.core import Tag, Options
from classytags.arguments import Argument, MultiKeywordArgument
import slumber

from django import template

register = template.Library()


def resize(svg, size):
    if not size:
        return svg
    root = etree.fromstring(svg)
    for k, v in size.iteritems():
        root.attrib[k] = v
    return etree.tostring(root)


class NounIcon(Tag):
    name = 'noun_icon'
    options = Options(
        Argument('name', required=True, default='world'),
        MultiKeywordArgument('size', required=False,),
        'as',
        Argument('varname', required=False, resolve=False)
    )

    def render_tag(self, context, name, varname, size=None):
        icon = ''
        api = slumber.API("http://thenounproject.com")
        result = api.search.get(q=name)
        if result['msg'] == 'Success':
            # Grab the first icon for this noun.
            name = result['svg'].keys()[0]
            svg = result['svg'][name]
            icon = resize(svg, size)

        if varname:
            context[varname] = icon
            return ''
        return icon

register.tag(NounIcon)



from setuptools import setup, find_packages

setup(
    name='django-noun-project',
    version='0.1',
    description='Support for the Noun Project inside Django',
    author='Philip Neustrom',
    author_email='philipn@gmail.com',
    url='http://github.com/philipn/django-noun-project/',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
    include_package_data=True,
    zip_safe=False,
    install_requires=['django-classy-tags', 'slumber'],
)
